Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Support.

Actions, resources, and condition keys for AWS Support - Service Authorization Reference

# Actions, resources, and condition keys for AWS Support

AWS Support (service prefix: `support` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Support
- Resource types defined by AWS Support
- Condition keys for AWS Support

## Actions defined by AWS Support

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

###### Note

AWS Support provides the ability to access, modify and resolve cases, as well as use Trusted Advisor actions. When you use the Support API to call Trusted Advisor-related actions, none of the "trustedadvisor:*" actions restrict your access. The "trustedadvisor:*" actions apply only to Trusted Advisor in the AWS Management Console.

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddAttachmentsToSet | Grants permission to add one or more attachments to an AWS Support case | Write |  |  |
AddCommunicationToCase | Grants permission to add a customer communication to an AWS Support case | Write |  |  |
CreateCase | Grants permission to creates a new AWS Support case | Write |  |  |
DescribeAttachment | Grants permission to describe attachment detail | Read |  |  |
DescribeCaseAttributes | Grants permission to allow secondary services to read AWS Support case attributes.This is an internally managed function | Read |  |  |
DescribeCases | Grants permission to list AWS Support cases that matches the given inputs | Read |  |  |
DescribeCommunications | Grants permission to list the communications and attachments for one or more AWS Support cases | Read |  |  |
DescribeCreateCaseOptions | Grants permission to describes the available options for creating a support case | Read |  |  |
DescribeIssueTypes | Grants permission to return issue types for AWS Support cases | Read |  |  |
DescribeServices | Grants permission to list AWS services and categories that applies to each service | Read |  |  |
DescribeSeverityLevels | Grants permission to list severity levels that can be assigned to an AWS Support case | Read |  |  |
DescribeSupportLevel | Grants permission to return the support level for an AWS Account identifier | Read |  |  |
DescribeSupportedLanguages | Grants permission to describes the available support languages for a given category code, service code and issue type | Read |  |  |
DescribeTrustedAdvisorCheckRefreshStatuses | Grants permission to get the status of a Trusted Advisor refresh check based on a list of check identifiers | Read |  |  |
DescribeTrustedAdvisorCheckResult | Grants permission to get the results of the Trusted Advisor check that has the specified check identifier | Read |  |  |
DescribeTrustedAdvisorCheckSummaries | Grants permission to get the summaries of the results of the Trusted Advisor checks that have the specified check identifiers | Read |  |  |
DescribeTrustedAdvisorChecks | Grants permission to get a list of all available Trusted Advisor checks, including name, identifier, category and description | Read |  |  |
InitiateCallForCase | Grants permission to initiate a call on AWS Support Center. This is an internally managed function | Write |  |  |
InitiateChatForCase | Grants permission to initiate a chat on AWS Support Center.This is an internally managed function | Write |  |  |
PutCaseAttributes | Grants permission to allow secondary services to attach attributes to AWS Support cases. This is an internally managed function | Write |  |  |
RateCaseCommunication | Grants permission to rate an AWS Support case communication | Write |  |  |
RefreshTrustedAdvisorCheck | Grants permission to requests a refresh of the Trusted Advisor check that has the specified check identifier | Write |  |  |
ResolveCase | Grants permission to resolve an AWS Support case | Write |  |  |
SearchForCases | Grants permission to return a list of AWS Support cases that matches the given inputs | Read |  |  |

## Resource types defined by AWS Support

AWS Support does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Support, specify `"Resource": "*"` in your policy.

## Condition keys for AWS Support

Support has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.